# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('episodeofcare', '0002_initial'),
        ('procedures', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='episodeofcarereasonvaluereference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_reason_value_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='episodeofcarereasonvaluecodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_reason_value_codeable_reference_reference', to='episodeofcare.episodeofcarereasonvaluereference'),
        ),
        migrations.AddField(
            model_name='episodeofcarereference',
            name='episode_of_care',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_reference_episode_of_care', to='episodeofcare.episodeofcare'),
        ),
        migrations.AddField(
            model_name='episodeofcarereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='episodeofcarestatushistory',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_status_history_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='episodeofcare',
            name='status_history',
            field=models.ManyToManyField(blank=True, related_name='episode_of_care_status_history', to='episodeofcare.episodeofcarestatushistory'),
        ),
    ]
