# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('encounters', '0001_initial'),
        ('locations', '0001_initial'),
        ('medicationrequests', '0001_initial'),
        ('patients', '0002_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='encounter',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_patient', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='encounter',
            name='subject_status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_subject_status', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='encounter',
            name='type',
            field=models.ManyToManyField(blank=True, related_name='encounter_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='encounter',
            name='virtual_service',
            field=models.ManyToManyField(blank=True, related_name='encounter_virtual_service', to='base.virtualservicedetails'),
        ),
        migrations.AddField(
            model_name='encounteradmission',
            name='admit_source',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_admission_admit_source', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='encounteradmission',
            name='destination',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='admission_destination', to='locations.locationorganizationreference'),
        ),
        migrations.AddField(
            model_name='encounteradmission',
            name='discharge_disposition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_admission_discharge_disposition', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='encounteradmission',
            name='origin',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='admission_origin', to='locations.locationorganizationreference'),
        ),
        migrations.AddField(
            model_name='encounteradmission',
            name='pre_admission_identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_admission_pre_admission_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='encounteradmission',
            name='re_admission',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_admission_re_admission', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='encounter',
            name='admission',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_admission', to='encounters.encounteradmission'),
        ),
        migrations.AddField(
            model_name='encounterbasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_based_on_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='encounterbasedonreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_based_on_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
    ]
