# Generated by Django 5.2 on 2025-04-10 13:09

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('genomicstudy', '0001_initial'),
        ('observations', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='regions_called',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_regions_called', to='observations.documentreferenceobservationreference'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='regions_studied',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_regions_studied', to='observations.documentreferenceobservationreference'),
        ),
    ]
