# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('bodystructures', '0002_initial'),
        ('claims', '0004_initial'),
        ('conditions', '0003_initial'),
        ('coverages', '0002_initial'),
        ('devices', '0001_initial'),
        ('encounters', '0003_initial'),
        ('explanationofbenefits', '0003_initial'),
        ('locations', '0001_initial'),
        ('medicationrequests', '0002_initial'),
        ('nutritionorders', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('visionprescriptions', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='explanationofbenefit',
            name='referral',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_referral', to='servicerequests.servicerequestreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='sub_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_sub_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitaccident',
            name='location_address',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_accident_location_address', to='base.address'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitaccident',
            name='location_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_accident_location_location', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitaccident',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_accident_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='accident',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_accident', to='explanationofbenefits.explanationofbenefitaccident'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='location_address',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_location_address', to='base.address'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='location_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_location_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='location_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_location_reference', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='serviced_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_serviced_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='add_item',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_add_item', to='explanationofbenefits.explanationofbenefitadditem'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='detail',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail', to='explanationofbenefits.explanationofbenefitadditemdetail'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail_sub_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail_sub_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='sub_detail',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail_sub_detail', to='explanationofbenefits.explanationofbenefitadditemdetailsubdetail'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalance',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_benefit_balance_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalance',
            name='network',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_benefit_balance_network', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalance',
            name='term',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_benefit_balance_term', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalance',
            name='unit',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_benefit_balance_unit', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='benefit_balance',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_benefit_balance', to='explanationofbenefits.explanationofbenefitbenefitbalance'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalancefinancial',
            name='allowed_money',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_benefit_balance_financial_allowed_money', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalancefinancial',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_benefit_balance_financial_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalancefinancial',
            name='used_money',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_benefit_balance_financial_used_money', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalance',
            name='financial',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_benefit_balance_financial', to='explanationofbenefits.explanationofbenefitbenefitbalancefinancial'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitcareteam',
            name='role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_care_team_role', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitcareteam',
            name='specialty',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_care_team_qualification', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='care_team',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_care_team', to='explanationofbenefits.explanationofbenefitcareteam'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitdiagnosis',
            name='diagnosis_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_diagnosis_diagnosis_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitdiagnosis',
            name='diagnosis_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_diagnosis_diagnosis_reference', to='conditions.conditionreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitdiagnosis',
            name='on_admission',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_diagnosis_on_admission', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitdiagnosis',
            name='type',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_diagnosis_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='diagnosis',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_diagnosis', to='explanationofbenefits.explanationofbenefitdiagnosis'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitentererreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_enterer_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitentererreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_enterer_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitentererreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_enterer_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitentererreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_enterer_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitentererreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_enterer_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='enterer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_enterer', to='explanationofbenefits.explanationofbenefitentererreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitevent',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_event_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitevent',
            name='when_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_event_when_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='event',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_event', to='explanationofbenefits.explanationofbenefitevent'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitinsurance',
            name='coverage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_insurance_coverage', to='coverages.coveragereference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='insurance',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_insurance', to='explanationofbenefits.explanationofbenefitinsurance'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='encounter',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='location_address',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_location_address', to='base.address'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='location_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_location_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='location_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_location_reference', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='serviced_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_serviced_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='item',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_item', to='explanationofbenefits.explanationofbenefititem'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemadjudication',
            name='amount',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_adjudication_amount', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemadjudication',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_adjudication_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemadjudication',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_adjudication_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemadjudication',
            name='reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_adjudication_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_adjudication', to='explanationofbenefits.explanationofbenefititemadjudication'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail_sub_detail_adjudication', to='explanationofbenefits.explanationofbenefititemadjudication'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail_adjudication', to='explanationofbenefits.explanationofbenefititemadjudication'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_adjudication', to='explanationofbenefits.explanationofbenefititemadjudication'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_adjudication', to='explanationofbenefits.explanationofbenefititemadjudication'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititembodysite',
            name='site',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_body_site_site', to='bodystructures.bodystructurecodeablereference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititembodysite',
            name='sub_site',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_body_site_sub_site', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='body_site',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_body_site', to='explanationofbenefits.explanationofbenefititembodysite'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='body_site',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_body_site', to='explanationofbenefits.explanationofbenefititembodysite'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_adjudication', to='explanationofbenefits.explanationofbenefititemadjudication'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='detail',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail', to='explanationofbenefits.explanationofbenefititemdetail'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_sub_detail_adjudication', to='explanationofbenefits.explanationofbenefititemadjudication'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_sub_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_sub_detail_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_sub_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_sub_detail_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='sub_detail',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_sub_detail', to='explanationofbenefits.explanationofbenefititemdetailsubdetail'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemrequestreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_request_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemrequestreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_request_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemrequestreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_request_reference_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemrequestreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_request_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemrequestreference',
            name='vision_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_request_reference_vision_prescription', to='visionprescriptions.visionprescription'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='request',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_request', to='explanationofbenefits.explanationofbenefititemrequestreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='request',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_request', to='explanationofbenefits.explanationofbenefititemrequestreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemreviewoutcome',
            name='decision',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_review_outcome_decision', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemreviewoutcome',
            name='pre_auth_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_review_outcome_pre_auth_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemreviewoutcome',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_review_outcome_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_review_outcome', to='explanationofbenefits.explanationofbenefititemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_review_outcome', to='explanationofbenefits.explanationofbenefititemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_review_outcome', to='explanationofbenefits.explanationofbenefititemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_review_outcome', to='explanationofbenefits.explanationofbenefititemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_review_outcome', to='explanationofbenefits.explanationofbenefititemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_review_outcome', to='explanationofbenefits.explanationofbenefititemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayee',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='payee',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_payee', to='explanationofbenefits.explanationofbenefitpayee'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayeepartyreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_party_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayeepartyreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_party_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayeepartyreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_party_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayeepartyreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_party_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayeepartyreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_party_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayeepartyreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_party_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayee',
            name='party',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_party', to='explanationofbenefits.explanationofbenefitpayeepartyreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayment',
            name='adjustment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payment_adjustment', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayment',
            name='adjustment_reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payment_adjustment_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayment',
            name='amount',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payment_amount', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayment',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payment_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayment',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payment_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='payment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_payment', to='explanationofbenefits.explanationofbenefitpayment'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprescriptionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_prescription_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprescriptionreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_prescription_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprescriptionreference',
            name='vision_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_prescription_reference_vision_prescription', to='visionprescriptions.visionprescription'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_prescription', to='explanationofbenefits.explanationofbenefitprescriptionreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprocedure',
            name='procedure_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_procedure_procedure_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprocedure',
            name='procedure_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_procedure_procedure_reference', to='procedures.procedurereference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprocedure',
            name='type',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_procedure_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprocedure',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_procedure_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='procedure',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_procedure', to='explanationofbenefits.explanationofbenefitprocedure'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprocessnote',
            name='language',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_process_note_language', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprocessnote',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_process_note_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='process_note',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_process_note', to='explanationofbenefits.explanationofbenefitprocessnote'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitproviderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_provider_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitproviderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_provider_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitproviderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_provider_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitproviderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_provider_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitcareteam',
            name='provider',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_care_team_provider', to='explanationofbenefits.explanationofbenefitproviderreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='provider',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_provider', to='explanationofbenefits.explanationofbenefitproviderreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='provider',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_provider', to='explanationofbenefits.explanationofbenefitproviderreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitrelated',
            name='claim',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_related_claim', to='claims.claimreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitrelated',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_related_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitrelated',
            name='relationship',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_related_relationship', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='related',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_funds_related', to='explanationofbenefits.explanationofbenefitrelated'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_reason', to='base.coding'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='timing_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_timing_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='value_attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_value_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='value_identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_value_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='value_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_value_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='value_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_value_reference', to='base.reference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='supporting_info',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_supporting_info', to='explanationofbenefits.explanationofbenefitsupportinginfo'),
        ),
        migrations.AddField(
            model_name='explanationofbenefittotal',
            name='amount',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_total_amount', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefittotal',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_total_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='total',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_total', to='explanationofbenefits.explanationofbenefittotal'),
        ),
    ]
