# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('enrollmentrequests', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='enrollmentrequest',
            name='candidate',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_request_candidate', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='enrollmentrequest',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='enrollment_request_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='enrollmentrequest',
            name='insurer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_request_insurer', to='base.organizationreference'),
        ),
        migrations.AddField(
            model_name='enrollmentrequestproviderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_request_provider_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='enrollmentrequestproviderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_request_provider_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='enrollmentrequestproviderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_request_provider_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='enrollmentrequestproviderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_request_provider_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='enrollmentrequest',
            name='provider',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_request_provider', to='enrollmentrequests.enrollmentrequestproviderreference'),
        ),
        migrations.AddField(
            model_name='enrollmentrequestsreference',
            name='enrollment_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_requests_reference_enrollment_request', to='enrollmentrequests.enrollmentrequest'),
        ),
        migrations.AddField(
            model_name='enrollmentrequestsreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_requests_reference_identifier', to='base.identifier'),
        ),
    ]
