# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('careteams', '0002_initial'),
        ('devices', '0001_initial'),
        ('groups', '0001_initial'),
        ('healthcareservices', '0001_initial'),
        ('locations', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='groupmanagingentityreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_managing_entity_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='group',
            name='managing_entity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_managing_entity', to='groups.groupmanagingentityreference'),
        ),
        migrations.AddField(
            model_name='groupmember',
            name='involvement',
            field=models.ManyToManyField(blank=True, related_name='group_member_involvement', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='groupmember',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='group',
            name='member',
            field=models.ManyToManyField(blank=True, related_name='group_member', to='groups.groupmember'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_location', to='locations.location'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='groupmember',
            name='entity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity', to='groups.groupmemberentityreference'),
        ),
        migrations.AddField(
            model_name='groupreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='groupreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_reference_identifier', to='base.identifier'),
        ),
    ]
