# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('devices', '0001_initial'),
        ('medicationstatements', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='medicationstatement',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='medicationstatementadherence',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_adherence_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationstatementadherence',
            name='reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_adherence_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationstatement',
            name='adherence',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_adherence', to='medicationstatements.medicationstatementadherence'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='medicationstatement',
            name='information_source',
            field=models.ManyToManyField(blank=True, related_name='medication_statement_information_source', to='medicationstatements.medicationstatementinformationsourcereference'),
        ),
        migrations.AddField(
            model_name='medicationstatementpartofreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_part_of_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='medicationstatementpartofreference',
            name='medication_statement',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_part_of_reference_medication_statement', to='medicationstatements.medicationstatement'),
        ),
    ]
