# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('careteams', '0002_initial'),
        ('conditions', '0003_initial'),
        ('devices', '0001_initial'),
        ('diagnosticreports', '0002_initial'),
        ('familymemberhistories', '0001_initial'),
        ('observations', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='familymemberhistory',
            name='patient',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='relationship',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_relationship', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='sex',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_sex', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_condition_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='onset_age',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_onset_age', to='base.age'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='onset_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_onset_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='onset_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_onset_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_outcome', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='condition',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_condition', to='familymemberhistories.familymemberhistorycondition'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipant',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_function', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='participant',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_participant', to='familymemberhistories.familymemberhistoryparticipant'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipant',
            name='actor',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor', to='familymemberhistories.familymemberhistoryparticipantactorreference'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_procedure_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_outcome', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='performed_age',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_performed_age', to='base.age'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='performed_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_performed_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='performed_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_performed_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='procedure',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_procedure', to='familymemberhistories.familymemberhistoryprocedure'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasoncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_codeable_reference_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_reason', to='familymemberhistories.familymemberhistoryreasoncodeablereference'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasonreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasonreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasonreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasoncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_codeable_reference_reference', to='familymemberhistories.familymemberhistoryreasonreference'),
        ),
    ]
