# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('flags', '0001_initial'),
        ('groups', '0002_initial'),
        ('locations', '0001_initial'),
        ('medications', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='flagauthorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_author_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='flagauthorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_author_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='flagauthorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_author_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='flagauthorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_author_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='flag',
            name='author',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_author', to='flags.flagauthorreference'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_location', to='locations.location'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_medication', to='medications.medication'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
    ]
