# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('clinicalimpressions', '0001_initial'),
        ('conditions', '0001_initial'),
        ('encounters', '0001_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='clinicalimpression',
            name='encounter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='clinical_impression_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='clinical_impression_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='performer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_performer', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='problem',
            field=models.ManyToManyField(blank=True, related_name='clinical_impression_problem', to='conditions.conditionallergyintolerancereference'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='prognosis_codeable_concept',
            field=models.ManyToManyField(blank=True, related_name='clinical_impression_prognosis_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='status_reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_status_reason', to='base.codeableconcept'),
        ),
    ]
