# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('explanationofbenefits', '0001_initial'),
        ('medicationrequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='explanationofbenefit',
            name='original_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_original_prescription', to='medicationrequests.medicationrequestreference'),
        ),
    ]
